monitoring

package
v0.0.0-...-9031c82 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 4, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package monitoring wraps components used for monitoring (logging, tracing, ...)

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FxModule

func FxModule() fx.Option

Types

type Monitor

type Monitor interface {
	Logger() logger.Logger
}

func New

func New(l logger.Logger) Monitor

Directories

Path Synopsis
Package logger describes interfaces for a logger.Logger and other support elements
Package logger describes interfaces for a logger.Logger and other support elements
loggertest
Package loggertest ...
Package loggertest ...
Package monitoringtest wraps test components for the monitoring package
Package monitoringtest wraps test components for the monitoring package

Jump to